# Example script for using the Subinitial Thermocouple Reader
# This script continuously reads all 8 thermocouple temperatures and records them to thermo_graph.csv

##########################################
# Setup Code
############################################

# Check for proper Python install
try:
    import numpy
except:
    print('A required Python library was not found. Please install "numpy" by using the command "pip install numpy".')
    input("Press [Enter] to exit..."); exit()
try:
    import subinitial.stacks as stacks
except:
    print('A required Python library was not found. Please install the Subinitial Python Library from '
          'www.subinitial.com.')
    input("Press [Enter] to exit..."); exit()

# Get thermocouple reader serial from user, for use in hostname
sn = input("\nEnter the 6-digit numerical serial number of the unit to gather data from, and press enter: ")
host = "stcr{}.local".format(sn)

############################################
# Application Code
############################################

# Connection: Connect to the thermocouple reader
print("Connecting to hostname: {} ...".format(host))
stcr = stacks.Stcr(host)

# File generation: Make a blank file / overwrite the old file & make column headers
print("Generating new thermo_graph.csv...")
save_file = "thermo_graph.csv" # Name of file to save the continuous data to
with open(save_file, "w", newline="") as f_handle:
    f_handle.write("Channel 0,Channel 1,Channel 2,Channel 3,Channel 4,Channel 5,Channel 6,Channel 7,Timestamp\n")

# Measuring: Run temperature measurements continuously
while 1:
    # Measure all 8 temperatures
    all_ch = stcr.measure(0, 1, 2, 3, 4, 5, 6, 7)

    # Print the data in the console
    for ch in all_ch:
        print("Ch {}: {:2.1f}C | ".format(ch.idx, ch), end="")
    print("")

    # Re-arrange and save the data to file
    row = [[val for val in all_ch if val is not None]]
    row[0].append(all_ch[0].timestamp)
    with open(save_file, "ab") as f_handle:
        numpy.savetxt(f_handle, row, delimiter=",")
